@@ -15,7 +15,7 @@ under the License.
 """
 import datetime as dt
 import logging
-from typing import Tuple, Union, List
+from typing import Tuple, Union, List, Dict
 
 from gs_quant.common import PositionType
 from gs_quant.instrument import Instrument
@@ -178,6 +178,10 @@ class GsPortfolioApi:
     def save_quote(cls, request: RiskRequest) -> str:
         return GsSession.current._post('/risk-internal/quote/save', request)['results']
 
+    @classmethod
+    def save_to_shadowbook(cls, request: RiskRequest, name: str) -> str:
+        return GsSession.current._put(f'/risk-internal/shadowbook/save/{name}', request)['results']
+
     @classmethod
     def get_risk_models_by_coverage(cls, portfolio_id: str, term: Term = Term.Medium):
         return GsSession.current._get(f'/portfolios/{portfolio_id}/models?sortByTerm={term.value}')['results']
@@ -189,13 +193,43 @@ class GsPortfolioApi:
     @classmethod
     def schedule_reports(cls,
                          portfolio_id: str,
-                         start_date: dt.date,
+                         start_date: dt.date = None,
                          end_date: dt.date = None,
                          backcast: bool = False) -> dict:
-        if end_date is None:
-            payload = {'startDate': start_date.isoformat()}
-        else:
-            payload = {'startDate': start_date.isoformat(), 'endDate': end_date.isoformat()}
-        if backcast:
-            payload['parameters'] = {'backcast': True}
+        payload = {'parameters': {'backcast': backcast}}
+        if start_date is not None:
+            payload['startDate'] = start_date.isoformat()
+        if end_date is not None:
+            payload['endDate'] = end_date.isoformat()
         return GsSession.current._post('/portfolios/{id}/schedule'.format(id=portfolio_id), payload)
+
+    @classmethod
+    def get_schedule_dates(cls,
+                           portfolio_id: str,
+                           backcast: bool = False) -> List[dt.date]:
+        results = GsSession.current._get(f'/portfolios/{portfolio_id}/schedule/dates?backcast={backcast}')
+        return [dt.datetime.strptime(results['startDate'], '%Y-%m-%d').date(),
+                dt.datetime.strptime(results['endDate'], '%Y-%m-%d').date()]
+
+    @classmethod
+    def get_custom_aum(cls,
+                       portfolio_id: str,
+                       start_date: dt.date = None,
+                       end_date: dt.date = None) -> dict:
+        url = f'/portfolios/{portfolio_id}/aum?'
+        if start_date:
+            url += f"&startDate={start_date.strftime('%Y-%m-%d')}"
+        if end_date:
+            url += f"&endDate={end_date.strftime('%Y-%m-%d')}"
+        return GsSession.current._get(url)['data']
+
+    @classmethod
+    def upload_custom_aum(cls,
+                          portfolio_id: str,
+                          aum_data: List[Dict],
+                          clear_existing_data: bool = None) -> dict:
+        url = f'/portfolios/{portfolio_id}/aum'
+        payload = {'data': aum_data}
+        if clear_existing_data:
+            url += '?clearExistingData=true'
+        return GsSession.current._post(url, payload)
