@@ -25,7 +25,7 @@ from enum import EnumMeta
 from functools import wraps
 from inspect import signature, Parameter
 import re
-from typing import Optional, Union, get_type_hints
+from typing import Iterable, Optional, Union, get_type_hints
 
 import inflection
 from dateutil.parser import isoparse
@@ -47,6 +47,14 @@ __setattr__ = object.__setattr__
 _underscore = inflection.underscore
 
 
+def is_iterable(o, t):
+    return isinstance(o, Iterable) and all(isinstance(it, t) for it in o)
+
+
+def is_instance_or_iterable(o, t):
+    return isinstance(o, t) or is_iterable(o, t)
+
+
 def camel_case_translate(f):
     @wraps(f)
     def wrapper(*args, **kwargs):
@@ -134,6 +142,9 @@ class Base(metaclass=ABCMeta):
     def __setattr__(self, key, value):
         properties = __getattribute__(self, 'properties')()
 
+        # tolist converts scalar or array to native python type if not already native.
+        value = getattr(value, "tolist", lambda: value)()
+
         if key.startswith('_') or key == 'name' or key in properties:
             return __setattr__(self, key, value)
 
