@@ -30,9 +30,9 @@ _logger = logging.getLogger(__name__)
 class User:
     def __init__(self,
                  user_id: str,
-                 name: str,
-                 email: str,
-                 company: str):
+                 name: str = None,
+                 email: str = None,
+                 company: str = None):
         self.__id = user_id
         self.__email = email
         self.__name = name
@@ -105,7 +105,7 @@ class User:
         """
         user_ids = user_ids if user_ids else []
         names = names if names else []
-        emails = emails if emails else []
+        emails = [email.lower() for email in emails] if emails else []
         companies = companies if companies else []
 
         if not user_ids + names + emails + companies:
@@ -376,6 +376,7 @@ class Entitlements:
                  admin: EntitlementBlock = None,
                  delete: EntitlementBlock = None,
                  display: EntitlementBlock = None,
+                 upload: EntitlementBlock = None,
                  edit: EntitlementBlock = None,
                  execute: EntitlementBlock = None,
                  plot: EntitlementBlock = None,
@@ -386,6 +387,7 @@ class Entitlements:
         self.__admin = admin if admin else EntitlementBlock()
         self.__delete = delete if delete else EntitlementBlock()
         self.__display = display if display else EntitlementBlock()
+        self.__upload = upload if upload else EntitlementBlock()
         self.__edit = edit if edit else EntitlementBlock()
         self.__execute = execute if execute else EntitlementBlock()
         self.__plot = plot if plot else EntitlementBlock()
@@ -418,6 +420,14 @@ class Entitlements:
     def display(self, value: EntitlementBlock):
         self.__display = value
 
+    @property
+    def upload(self):
+        return self.__upload
+
+    @upload.setter
+    def upload(self, value: EntitlementBlock):
+        self.__upload = value
+
     @property
     def edit(self):
         return self.__edit
@@ -486,6 +496,8 @@ class Entitlements:
             target_entitlements.delete = self.delete.to_list()
         if not self.display.is_empty():
             target_entitlements.display = self.display.to_list()
+        if not self.upload.is_empty():
+            target_entitlements.upload = self.upload.to_list()
         if not self.edit.is_empty():
             target_entitlements.edit = self.edit.to_list()
         if not self.execute.is_empty():
@@ -514,6 +526,7 @@ class Entitlements:
         all_entitled += self.admin.to_list(True, 'admin')
         all_entitled += self.delete.to_list(True, 'delete')
         all_entitled += self.display.to_list(True, 'display')
+        all_entitled += self.upload.to_list(True, 'upload')
         all_entitled += self.edit.to_list(True, 'edit')
         all_entitled += self.execute.to_list(True, 'execute')
         all_entitled += self.plot.to_list(True, 'plot')
