@@ -13,6 +13,6 @@ KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 """
-from .core import PricingCache, PricingContext
+from .core import PricingCache, PricingContext, PositionContext
 from .historical import HistoricalPricingContext, BackToTheFuturePricingContext
 from .markets import *
