@@ -95,47 +95,6 @@ class CustomBasketStyles(EnumBase, Enum):
         return self.value
 
 
-class FundamentalsMetrics(EnumBase, Enum):
-    """ Metric for the associated asset """
-    DIVIDEND_YIELD = 'Dividend Yield'
-    EARNINGS_PER_SHARE = 'Earnings per Share'
-    EARNINGS_PER_SHARE_POSITIVE = 'Earnings per Share Positive'
-    NET_DEBT_TO_EBITDA = 'Net Debt to EBITDA'
-    PRICE_TO_BOOK = 'Price to Book'
-    PRICE_TO_CASH = 'Price to Cash'
-    PRICE_TO_EARNINGS = 'Price to Earnings'
-    PRICE_TO_EARNINGS_POSITIVE = 'Price to Earnings Positive'
-    PRICE_TO_SALES = 'Price to Sales'
-    RETURN_ON_EQUITY = 'Return on Equity'
-    SALES_PER_SHARE = 'Sales per Share'
-
-    def __repr__(self):
-        return self.value
-
-    @classmethod
-    def to_list(cls):
-        return [metric.value for metric in cls]
-
-
-class FundamentalMetricPeriod(EnumBase, Enum):
-    """ Period for the relevant metric """
-    ONE_YEAR = '1y'
-    TWO_YEARS = '2y'
-    THREE_YEARS = '3y'
-
-    def __repr__(self):
-        return self.value
-
-
-class FundamentalMetricPeriodDirection(EnumBase, Enum):
-    """	Direction of the outlook period """
-    FORWARD = 'forward'
-    TRAILING = 'trailing'
-
-    def __repr__(self):
-        return self.value
-
-
 class IndicesDatasets(EnumBase, Enum):
     """ Indices Datasets """
     BASKET_FUNDAMENTALS = 'BASKET_FUNDAMENTALS'
@@ -143,11 +102,26 @@ class IndicesDatasets(EnumBase, Enum):
     GIRBASKETCONSTITUENTS = 'GIRBASKETCONSTITUENTS'
     GSBASKETCONSTITUENTS = 'GSBASKETCONSTITUENTS'
     GSCB_FLAGSHIP = 'GSCB_FLAGSHIP'
+    STS_FUNDAMENTALS = 'STS_FUNDAMENTALS'
+    STS_INDICATIVE_LEVELS = 'STS_INDICATIVE_LEVELS'
 
     def __repr__(self):
         return self.value
 
 
+class PriceType(EnumBase, Enum):
+    """ Index Price Types """
+    INDICATIVE_CLOSE_PRICE = 'indicativeClosePrice'
+    OFFICIAL_CLOSE_PRICE = 'officialClosePrice'
+
+    def __repr__(self):
+        return self.value
+
+    @classmethod
+    def to_list(cls):
+        return [price_type for price_type in cls]
+
+
 class Region(EnumBase, Enum):
     """ Region of the index """
     AMERICAS = 'Americas'
@@ -203,6 +177,22 @@ class ReturnType(EnumBase, Enum):
         return self.value
 
 
+class STSIndexType(EnumBase, Enum):
+    """ STS Types """
+
+    ACCESS = 'Access'
+    MULTI_ASSET_ALLOCATION = 'Multi-Asset Allocation'
+    RISK_PREMIA = 'Risk Premia'
+    SYSTEMATIC_HEDGING = 'Systematic Hedging'
+
+    def __repr__(self):
+        return self.value
+
+    @classmethod
+    def to_list(cls):
+        return [sts_type.value for sts_type in cls]
+
+
 class WeightingStrategy(EnumBase, Enum):
     """ Strategy used to price the index's position set """
     EQUAL = 'Equal'
@@ -463,13 +453,13 @@ def get_flagships_constituents(fields: [str] = [],
             start_date = dt.datetime.strptime(b['historyStartDate'], '%Y-%m-%d').date()
             start_date = start_date if start < start_date else start
             if _type == BasketType.CUSTOM_BASKET.value:
-                data = GsDataApi.query_data(query=DataQuery(where=dict(assetId=_id),
+                data = GsDataApi.query_data(query=DataQuery(where=dict(assetId=_id, fields=fields),
                                             startDate=start_date, endDate=end),
                                             dataset_id=IndicesDatasets.GSBASKETCONSTITUENTS.value)
                 basket_map[_id].update(constituents=data)
                 cbs.append(basket_map[_id])
             elif _type == BasketType.RESEARCH_BASKET.value:
-                data = GsDataApi.query_data(query=DataQuery(where=dict(assetId=_id),
+                data = GsDataApi.query_data(query=DataQuery(where=dict(assetId=_id, fields=fields),
                                             startDate=start_date, endDate=end),
                                             dataset_id=IndicesDatasets.GIRBASKETCONSTITUENTS.value)
                 basket_map[_id].update(constituents=data)
