@@ -33,6 +33,7 @@ from gs_quant.priceable import PriceableImpl
 from gs_quant.risk import RiskMeasure, ResolvedInstrumentValues
 from gs_quant.risk.results import CompositeResultFuture, PortfolioRiskResult, PortfolioPath, PricingFuture
 from gs_quant.target.common import RiskPosition
+from gs_quant.target.portfolios import Portfolio as MarqueePortfolio
 from gs_quant.target.portfolios import Position, PositionSet, RiskRequest, PricingDateAndMarketDataAsOf
 
 _logger = logging.getLogger(__name__)
@@ -187,7 +188,12 @@ class Portfolio(PriceableImpl):
         return tuple(unique_everseen(portfolios))
 
     def subset(self, paths: Iterable[PortfolioPath], name=None):
-        return Portfolio(tuple(self[p] for p in paths), name=name)
+        # Do our paths represent a single portfolio?
+        paths_tuple = tuple(paths)
+        if len(paths_tuple) == 1 and isinstance(self[paths_tuple[0]], Portfolio):
+            return self[paths_tuple[0]]
+        else:
+            return Portfolio(tuple(self[p] for p in paths_tuple), name=name)
 
     @staticmethod
     def __from_internal_positions(id_type: str, positions_id):
@@ -262,23 +268,15 @@ class Portfolio(PriceableImpl):
         else:
             if not self.__name:
                 raise ValueError('name not set')
-
-            try:
-                self.__id = GsPortfolioApi.get_portfolio_by_name(self.__name).id
-                if not overwrite:
-                    raise RuntimeError(
-                        f'Portfolio {self.__name} with id {self.__id} already exists. Use overwrite=True to overwrite')
-            except ValueError:
-                from gs_quant.target.portfolios import Portfolio as MarqueePortfolio
-                self.__id = GsPortfolioApi.create_portfolio(MarqueePortfolio('USD', self.__name)).id
-                _logger.info(f'Created Marquee portfolio {self.__name} with id {self.__id}')
+            self.__id = GsPortfolioApi.create_portfolio(MarqueePortfolio('USD', self.__name)).id
+            _logger.info(f'Created Marquee portfolio {self.__name} with id {self.__id}')
 
         position_set = PositionSet(
             position_date=self.__position_context.position_date,
             positions=tuple(Position(asset_id=GsAssetApi.get_or_create_asset_from_instrument(i))
                             for i in self.instruments))
-
-        GsPortfolioApi.update_positions(self.__id, [position_set])
+        if len(position_set.positions) > 0:
+            GsPortfolioApi.update_positions(self.__id, [position_set])
 
     def save_as_quote(self, overwrite: Optional[bool] = False):
         if self.portfolios:
@@ -303,6 +301,21 @@ class Portfolio(PriceableImpl):
             self.__id = GsPortfolioApi.save_quote(request)
             _logger.info(f'Created Structuring with id {self.__id}')
 
+    def save_to_shadowbook(self, name: str):
+        if self.portfolios:
+            raise ValueError('Cannot save portfolios with nested portfolios')
+
+        pricing_context = self.__pricing_context
+
+        request = RiskRequest(
+            tuple(RiskPosition(instrument=i, quantity=i.instrument_quantity) for i in self.instruments),
+            (ResolvedInstrumentValues,),
+            pricing_and_market_data_as_of=(PricingDateAndMarketDataAsOf(pricing_date=pricing_context.pricing_date,
+                                                                        market=pricing_context.market),)
+        )
+        status = GsPortfolioApi.save_to_shadowbook(request, name)
+        print(f'Save to shadowbook status - {status}')
+
     @classmethod
     def from_frame(cls, data: pd.DataFrame, mappings: dict = None):
         def get_value(this_row: pd.Series, attribute: str):
