@@ -13,30 +13,40 @@ KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 """
-
-import datetime as dt
+import calendar
+import datetime
+import functools
 import json
+import logging
 import threading
+import time
 from abc import ABCMeta, abstractmethod
-from enum import Enum
-from typing import Dict, Optional, Tuple, Union
+from copy import deepcopy
+from enum import auto
+from functools import partial
+from typing import Dict, Tuple, Generator
 
+import backoff
 import cachetools
-import pandas as pd
 import pytz
-from pydash import get
+from dateutil.relativedelta import relativedelta
 
-from gs_quant.api.gs.assets import GsAssetApi, GsAsset, AssetClass, AssetParameters, \
+from gs_quant.api.gs.assets import GsAsset, AssetParameters, \
     AssetType as GsAssetType, Currency
+from gs_quant.api.utils import ThreadPoolManager
 from gs_quant.base import get_enum_value
 from gs_quant.common import DateLimit
 from gs_quant.data import DataMeasure, DataFrequency
 from gs_quant.data.coordinate import DataDimensions
 from gs_quant.data.coordinate import DateOrDatetime
+from gs_quant.data.core import IntervalFrequency, DataAggregationOperator
 from gs_quant.entities.entity import Entity, EntityIdentifier, EntityType, PositionedEntity
-from gs_quant.errors import MqValueError
+from gs_quant.errors import MqValueError, MqTypeError, MqRequestError
 from gs_quant.json_encoder import JSONEncoder
 from gs_quant.markets import PricingContext
+from gs_quant.markets.indices_utils import *
+
+_logger = logging.getLogger(__name__)
 
 
 class ExchangeCode(Enum):
@@ -98,9 +108,15 @@ class AssetType(Enum):
     #: Swap
     SWAP = "Swap"
 
+    #: Swaption
+    SWAPTION = "Swaption"
+
     #: Option
     OPTION = "Option"
 
+    #: Binary
+    BINARY = "Binary"
+
     #: Commodity Reference Price
     COMMODITY_REFERENCE_PRICE = "Commodity Reference Price"
 
@@ -140,6 +156,46 @@ class AssetType(Enum):
     #: Default Swap
     DEFAULT_SWAP = "Default Swap"
 
+    #: Systematic Hedging
+    SYSTEMATIC_HEDGING = 'Systematic Hedging'
+
+    #: Access
+    ACCESS = 'Access'
+
+    #: Risk Premia
+    RISK_PREMIA = 'Risk Premia'
+
+    #: Multi Asset Allocation
+    MULTI_ASSET_ALLOCATION = 'Multi-Asset Allocation'
+
+    # Sec Master types
+
+    ADR = 'ADR'
+    GDR = 'GDR'
+    DUTCH_CERT = 'Dutch Cert'
+    NYRS = 'NY Reg Shrs'
+    RECEIPT = 'Receipt'
+    UNIT = 'Unit'
+    MUTUAL_FUND = 'Mutual Fund'
+    RIGHT = 'Right'
+    PREFERRED = 'Preferred'
+    MISC = 'Misc.'
+    REIT = 'REIT'
+    PRIVATE_COMP = 'Private Comp'
+    PREFERENCE = 'Preference'
+    LIMITED_PARTNERSHIP = 'Ltd Part'
+    TRACKING_STOCK = 'Tracking Stk'
+    ROYALTY_TRUST = 'Royalty Trst'
+    CLOSED_END_FUND = 'Closed-End Fund'
+    OPEN_END_FUND = 'Open-End Fund'
+    FUND_OF_FUNDS = 'Fund of Funds'
+    MLP = 'MLP'
+    STAPLED_SECURITY = 'Stapled Security'
+    SAVINGS_SHARE = 'Savings Share'
+    EQUITY_WRT = 'Equity WRT'
+    # ETF already defined
+    SAVINGS_PLAN = 'Savings Plan'
+
 
 class AssetIdentifier(EntityIdentifier):
     """Asset type enumeration
@@ -160,6 +216,21 @@ class AssetIdentifier(EntityIdentifier):
     GSID = "GSID"
 
 
+class SecurityIdentifier(EntityIdentifier):
+    GSID = "gsid"
+    RIC = "ric"
+    ID = "id"
+    CUSIP = "cusip"
+    SEDOL = "sedol"
+    ISIN = "isin"
+    TICKER = "ticker"
+    BBID = "bbid"
+    BCID = "bcid"
+    GSS = "gss"
+    PRIMEID = "primeId"
+    BBG = "bbg"
+
+
 class ReturnType(Enum):
     """Index return type
 
@@ -187,10 +258,19 @@ class Asset(Entity, metaclass=ABCMeta):
         self.exchange = exchange
         self.currency = currency
         self.parameters = parameters
+        self.entity = entity
 
     def get_marquee_id(self):
         return self.__id
 
+    def get_url(self) -> str:
+        """
+        Retrieve url to asset's product page on Marquee
+        """
+        env = '-dev-ext.web' if 'dev' in get(GsSession, 'current.domain', '') else ''
+        env = '-qa' if 'qa' in get(GsSession, 'current.domain', '') else env
+        return f'https://marquee{env}.gs.com/s/products/{self.__id}/summary'
+
     def get_identifiers(self, as_of: dt.date = None) -> dict:
         """
         Get asset identifiers
@@ -296,7 +376,9 @@ class Asset(Entity, metaclass=ABCMeta):
                         dimensions: Optional[DataDimensions] = None,
                         frequency: Optional[DataFrequency] = None,
                         start: Optional[DateOrDatetime] = None,
-                        end: Optional[DateOrDatetime] = None) -> pd.Series:
+                        end: Optional[DateOrDatetime] = None,
+                        dates: List[dt.date] = None,
+                        operator: DataAggregationOperator = None) -> pd.Series:
         """
         Get asset series
 
@@ -329,8 +411,8 @@ class Asset(Entity, metaclass=ABCMeta):
 
         coordinate = self.get_data_coordinate(measure, dimensions, frequency)
         if coordinate is None:
-            raise MqValueError(f"No data co-ordinate found for these parameters: {measure, dimensions, frequency}")
-        return coordinate.get_series(start=start, end=end)
+            raise MqValueError(f"No data coordinate found for parameters: {measure, dimensions, frequency}")
+        return coordinate.get_series(start=start, end=end, dates=dates, operator=operator)
 
     def get_latest_close_price(self) -> float:
         coordinate = self.get_data_coordinate(DataMeasure.CLOSE_PRICE, None, DataFrequency.DAILY)
@@ -370,6 +452,64 @@ class Asset(Entity, metaclass=ABCMeta):
         """
         return self.get_data_series(DataMeasure.CLOSE_PRICE, None, DataFrequency.DAILY, start, end)
 
+    def get_hloc_prices(self,
+                        start: dt.date = DateLimit.LOW_LIMIT.value,
+                        end: dt.date = dt.date.today(),
+                        interval_frequency: IntervalFrequency = IntervalFrequency.DAILY) -> pd.DataFrame:
+        """
+        Get high, low, open, close (hloc) prices
+
+        :return: dataframe indexed by datetimes bucketed by the given interval_frequency with High, Low, Open, and Close
+        columns
+
+        **Usage**
+
+        Get high, low, open, and close prices for an asset for the given interval frequency.
+
+        **Examples**
+
+        Get hloc price series:
+
+        >>> from gs_quant.markets.securities import SecurityMaster
+        >>>
+        >>> gs = SecurityMaster.get_asset("GS", AssetIdentifier.TICKER)
+        >>> gs.get_hloc_prices()
+
+        **See also**
+
+        :class:`DataMeasure`
+        :func:`get_close_prices`
+        """
+        if interval_frequency == IntervalFrequency.DAILY:
+            dates = None
+            use_field = False
+        elif interval_frequency == IntervalFrequency.MONTHLY:
+            d = dt.date(start.year, start.month, 1)
+            dates = [d, dt.date(d.year, d.month, calendar.monthrange(d.year, d.month)[-1])]
+            d += relativedelta(months=1)
+            while d < end:
+                dates.append(dt.date(d.year, d.month, calendar.monthrange(d.year, d.month)[-1]))
+                d += relativedelta(months=1)
+            dates.append(end)
+            use_field = True
+        else:
+            raise MqValueError(f'Unsupported IntervalFrequency {interval_frequency.value} for get_hloc_prices')
+
+        tasks = [
+            partial(self.get_data_series, DataMeasure.ADJUSTED_HIGH_PRICE, None, DataFrequency.DAILY, start, end,
+                    dates=dates, operator=DataAggregationOperator.MAX if use_field else None),
+            partial(self.get_data_series, DataMeasure.ADJUSTED_LOW_PRICE, None, DataFrequency.DAILY, start, end,
+                    dates=dates, operator=DataAggregationOperator.MIN if use_field else None),
+            partial(self.get_data_series, DataMeasure.ADJUSTED_OPEN_PRICE, None, DataFrequency.DAILY, start, end,
+                    dates=dates, operator=DataAggregationOperator.FIRST if use_field else None),
+            partial(self.get_data_series, DataMeasure.ADJUSTED_CLOSE_PRICE, None, DataFrequency.DAILY, start, end,
+                    dates=dates, operator=DataAggregationOperator.LAST if use_field else None)
+        ]
+
+        results = ThreadPoolManager.run_async(tasks)
+        df = pd.DataFrame({'high': results[0], 'low': results[1], 'open': results[2], 'close': results[3]})
+        return df.dropna()
+
     @abstractmethod
     def get_type(self) -> AssetType:
         """Overridden by sub-classes to return security type"""
@@ -788,35 +928,6 @@ class Forward(Asset):
         return AssetType.FORWARD
 
 
-class Index(Asset, PositionedEntity):
-    """Index Asset
-
-    Index which tracks an evolving portfolio of securities, and can be traded through cash or derivatives markets
-    """
-
-    def __init__(self,
-                 id_: str,
-                 asset_class: AssetClass,
-                 name: str,
-                 exchange: Optional[str] = None,
-                 currency: Optional[Currency] = None,
-                 entity: Optional[Dict] = None):
-        Asset.__init__(self, id_, asset_class, name, exchange, currency, entity=entity)
-        PositionedEntity.__init__(self, id_, EntityType.ASSET)
-
-    def get_type(self) -> AssetType:
-        return AssetType.INDEX
-
-    def get_currency(self) -> Optional[Currency]:
-        return self.currency
-
-    def get_return_type(self) -> ReturnType:
-        if self.parameters is None or self.parameters.index_return_type is None:
-            return ReturnType.TOTAL_RETURN
-
-        return ReturnType(self.parameters.index_return_type)
-
-
 class ETF(Asset, PositionedEntity):
     """ETF Asset
 
@@ -840,6 +951,39 @@ class ETF(Asset, PositionedEntity):
         return self.currency
 
 
+class Swaption(Asset):
+    """Swaption
+
+    Represents a swaption.
+
+    """
+
+    def __init__(self,
+                 id_: str,
+                 name: str,
+                 entity: Optional[Dict] = None):
+        Asset.__init__(self, id_, AssetClass.Rates, name, entity=entity)
+
+    def get_type(self) -> AssetType:
+        return AssetType.SWAPTION
+
+
+class Binary(Asset):
+    """Binary
+    Represents a binary.
+    """
+
+    def __init__(self,
+                 id_: str,
+                 name: str,
+                 asset_class: AssetClass,
+                 entity: Optional[Dict] = None):
+        Asset.__init__(self, id_, asset_class, name, entity=entity)
+
+    def get_type(self) -> AssetType:
+        return AssetType.BINARY
+
+
 class DefaultSwap(Asset):
     """DefaultSwap
 
@@ -857,6 +1001,31 @@ class DefaultSwap(Asset):
         return AssetType.DEFAULT_SWAP
 
 
+class SecurityMasterSource(Enum):
+    ASSET_SERVICE = auto()
+    SECURITY_MASTER = auto()
+
+
+class Security:
+    def __init__(self, json: dict):
+        for k, v in json.items():
+            if k == 'identifiers':
+                self._ids = {inner_k: inner_v for inner_k, inner_v in v.items()}
+            else:
+                setattr(self, k, v)
+
+    def __str__(self):
+        return str({k: v for k, v in self.__dict__.items() if not k.startswith("_")})
+
+    def get_identifiers(self):
+        return deepcopy(self._ids)
+
+
+@backoff.on_exception(backoff.expo, MqRequestError, giveup=lambda e: e.status != 429)
+def _get_with_retries(url, payload):
+    return GsSession.current._get(url, payload=payload)
+
+
 class SecurityMaster:
     """Security Master
 
@@ -871,6 +1040,8 @@ class SecurityMaster:
     :class:`Asset`
 
      """
+    _source = SecurityMasterSource.ASSET_SERVICE
+    _page_size = 1000
 
     @classmethod
     def __gs_asset_to_asset(cls, gs_asset: GsAsset) -> Asset:
@@ -886,9 +1057,11 @@ class SecurityMaster:
 
         if asset_type in (
                 GsAssetType.Index.value,
-                GsAssetType.Risk_Premia.value,
                 GsAssetType.Access.value,
-                GsAssetType.Multi_Asset_Allocation.value):
+                GsAssetType.Multi_Asset_Allocation.value,
+                GsAssetType.Risk_Premia.value,
+                GsAssetType.Systematic_Hedging.value):
+            from gs_quant.markets.index import Index
             return Index(gs_asset.id, gs_asset.assetClass, gs_asset.name, gs_asset.exchange, gs_asset.currency,
                          entity=asset_entity)
 
@@ -960,7 +1133,13 @@ class SecurityMaster:
             return Fund(gs_asset.id, gs_asset.name, gs_asset.assetClass, entity=asset_entity)
 
         if asset_type == GsAssetType.Default_Swap.value:
-            return DefaultSwap(gs_asset.id, gs_asset.name, entity=asset_entity)
+            return DefaultSwap(gs_asset.id, gs_asset.asset_class, entity=asset_entity)
+
+        if asset_type == GsAssetType.Swaption.value:
+            return Swaption(gs_asset.id, gs_asset.name, entity=asset_entity)
+
+        if asset_type == GsAssetType.Binary.value:
+            return Binary(gs_asset.id, gs_asset.name, gs_asset.assetClass, entity=asset_entity)
 
         raise TypeError(f'unsupported asset type {asset_type}')
 
@@ -979,14 +1158,19 @@ class SecurityMaster:
 
         return asset_map.get(asset_type)
 
+    @classmethod
+    def set_source(cls, source: SecurityMasterSource):
+        cls._source = source
+
     @classmethod
     def get_asset(cls,
                   id_value: str,
-                  id_type: AssetIdentifier,
+                  id_type: Union[AssetIdentifier, SecurityIdentifier],
                   as_of: Union[dt.date, dt.datetime] = None,
                   exchange_code: ExchangeCode = None,
                   asset_type: AssetType = None,
-                  sort_by_rank: bool = False) -> Asset:
+                  sort_by_rank: bool = False,
+                  fields: Optional[List[str]] = None) -> Union[Asset, Security]:
         """
         Get an asset by identifier and identifier type
 
@@ -996,6 +1180,7 @@ class SecurityMaster:
         :param asset_type: asset type
         :param as_of: As of date for query
         :param sort_by_rank: whether to sort assets by rank.
+        :param fields: asset fields to return
         :return: Asset object or None
 
         **Usage**
@@ -1023,6 +1208,12 @@ class SecurityMaster:
         :func:`get_many_assets`
 
         """
+        if cls._source == SecurityMasterSource.SECURITY_MASTER:
+            if not isinstance(id_type, SecurityIdentifier):
+                raise MqTypeError('expected a security identifier')
+            if exchange_code or asset_type or sort_by_rank:
+                raise NotImplementedError('argument not implemented for Security Master (supported in Asset Service)')
+            return cls._get_security(id_value, id_type, as_of=as_of, fields=fields)
 
         if not as_of:
             as_of = PricingContext.current.pricing_date
@@ -1054,3 +1245,164 @@ class SecurityMaster:
 
         if result:
             return cls.__gs_asset_to_asset(result)
+
+    @classmethod
+    def _get_security(cls,
+                      id_value: str,
+                      id_type: SecurityIdentifier,
+                      as_of: Union[dt.date, dt.datetime] = None,
+                      fields: Optional[List[str]] = None) -> Optional[Security]:
+        as_of = as_of or datetime.datetime(2100, 1, 1)
+        type_ = id_type.value
+        params = {
+            type_: id_value,
+            'asOfDate': as_of.strftime('%Y-%m-%d')  # TODO: update endpoint to take times
+        }
+        if fields is not None:
+            if 'identifiers' not in fields:
+                fields.append('identifiers')
+            params['fields'] = fields
+
+        r = GsSession.current._get('/markets/securities', payload=params)
+        if r['totalResults'] == 0:
+            return None
+        return Security(r['results'][0])
+
+    @classmethod
+    def get_identifiers(cls, id_values: List[str], id_type: SecurityIdentifier, as_of: datetime.datetime = None,
+                        start: datetime.datetime = None, end: datetime.datetime = None) -> dict:
+        """
+        Get identifiers for given assets.
+
+        :param id_values: identifier values e.g. ['GS UN']
+        :param id_type: identifier type e.g. BBID
+        :param as_of: point in time to use for resolving given ids to assets
+        :param start: restrict results to ids updated after this time
+        :param end: restrict results to ids updated before this time
+        :return: dict from IDs (of id_type) to available identifiers
+        """
+        if cls._source != SecurityMasterSource.SECURITY_MASTER:
+            raise NotImplementedError("method not available when using Asset Service")
+
+        as_of = as_of or datetime.datetime.now()
+        start = start or datetime.datetime(1970, 1, 1)
+        end = end or datetime.datetime(2100, 1, 1)
+
+        type_ = id_type.value
+        params = {
+            type_: id_values,
+            'fields': ['id', 'identifiers'],
+            'asOfDate': as_of.strftime('%Y-%m-%d')  # TODO: update endpoint to take times
+        }
+
+        r = GsSession.current._get('/markets/securities', payload=params)
+        id_map = {}
+        for asset in r['results']:
+            id_map[asset['identifiers'][type_]] = asset['id']
+
+        if len(id_map) == 0:
+            return {}
+
+        output = {}
+        for k, v in id_map.items():
+            r = GsSession.current._get(f'/markets/securities/{v}/identifiers')
+            piece = []
+            for e in r['results']:
+                time_str = e['updateTime'].split('.')[0]
+                if time_str.endswith('Z'):
+                    time_str = time_str[0:-1]
+                time = datetime.datetime.strptime(time_str, '%Y-%m-%dT%H:%M:%S')
+                if start <= time <= end:
+                    piece.append(e)
+            output[k] = piece
+
+        return output
+
+    @staticmethod
+    def asset_type_to_str(asset_class: AssetClass, asset_type: AssetType):
+        if asset_type == AssetType.STOCK:
+            return "Common Stock"
+        if asset_type == AssetType.INDEX and asset_class == AssetClass.Equity:
+            return "Equity Index"
+        return asset_type.value
+
+    @classmethod
+    def get_all_identifiers_gen(cls, class_: AssetClass = None, types: Optional[List[AssetType]] = None,
+                                as_of: datetime.datetime = None, *, id_type: SecurityIdentifier = SecurityIdentifier.ID,
+                                use_offset_key=True, sleep=0.5) -> Generator[dict, None, None]:
+        """
+        Get identifiers for all matching assets. Returns a generator iterator so that the caller can load each page of
+        results using next().
+
+        :param class_: if not None, restrict results to assets of given class e.g. Equity
+        :param types: if not None, restrict results to given types e.g. Stock
+        :param as_of: point in time for which identifiers are fetched
+        :param id_type: identifier type to use for keys of results
+        :param use_offset_key: whether to use offset keys for pagination (required for large result sets)
+        :param sleep: seconds to sleep between API calls (to avoid server-side throttling)
+        :return: a generator iterator that yields dicts from id (of the id_type) to available identifiers
+        """
+        if cls._source != SecurityMasterSource.SECURITY_MASTER:
+            raise NotImplementedError("method not available when using Asset Service")
+
+        as_of = as_of or datetime.datetime.now()
+        if types is not None:
+            p = functools.partial(cls.asset_type_to_str, class_)
+            types = set(map(p, types))
+
+        params = {
+            'fields': ['id', 'identifiers', 'assetClass', 'type'],
+            'asOfDate': as_of.date(),
+            'limit': cls._page_size
+        }
+
+        while True:
+            r = _get_with_retries('/markets/securities', params)
+            if r['totalResults'] == 0:
+                return
+
+            output = {}
+            for e in r['results']:
+                # TODO: perform filtering on server side
+                if (class_ is None or e['assetClass'] == class_.value) and (types is None or e['type'] in types):
+                    box = e['identifiers']
+                    key = box[id_type.value]
+                    if key in box:
+                        _logger.debug(f'encountered duplicate key {key}')
+                    output[key] = box
+
+            yield output
+            if use_offset_key:
+                if 'offsetKey' not in r:
+                    return
+                params['offsetKey'] = r['offsetKey']
+            else:
+                params['offset'] = params.get('offset', 0) + cls._page_size
+                if params['offset'] + params['limit'] > 10000:
+                    _logger.warning('reached result size limit; enable use of offset keys to retrieve all results')
+                    return
+            time.sleep(sleep)
+
+    @classmethod
+    def get_all_identifiers(cls, class_: AssetClass = None, types: Optional[List[AssetType]] = None,
+                            as_of: datetime.datetime = None, *, id_type: SecurityIdentifier = SecurityIdentifier.ID,
+                            use_offset_key=True, sleep=0.5) -> Dict[str, dict]:
+        """
+        Get identifiers for all matching assets.
+
+        :param class_: if not None, restrict results to assets of given class e.g. Equity
+        :param types: if not None, restrict results to given types e.g. Stock
+        :param as_of: point in time for which identifiers are fetched
+        :param id_type: identifier type to use for keys of results
+        :param use_offset_key: whether to use offset keys for pagination (required for large result sets)
+        :param sleep: seconds to sleep between API calls (to avoid server-side throttling)
+        :return: dict from id (of the id_type) to available identifiers
+        """
+        gen = cls.get_all_identifiers_gen(class_, types, as_of, id_type=id_type, use_offset_key=use_offset_key,
+                                          sleep=sleep)
+        accumulator = dict()
+        while True:
+            try:
+                accumulator.update(next(gen))
+            except StopIteration:
+                return accumulator
