@@ -19,4 +19,5 @@ from .measures import *
 from .scenarios import MarketDataShockBasedScenario
 from gs_quant.target.portfolios import LiquidityRequest
 from gs_quant.target.risk import LiborFallbackScenario, CarryScenario, CompositeScenario, CurveScenario, IndexCurveShift,\
-    LiquidityResponse, MarketDataPattern, MarketDataScenario, MarketDataShock, MarketDataShockType, RiskRequest, RollFwd
+    LiquidityResponse, MarketDataPattern, MarketDataScenario, MarketDataShock, MarketDataShockType, RiskRequest, RollFwd,\
+    CurveOverlay
