@@ -13,16 +13,27 @@ KIND, either express or implied.  See the License for the
 specific language governing permissions and limitations
 under the License.
 """
+import copy
 from typing import Optional, Union
 
-from gs_quant.base import Market
-from gs_quant.common import AssetClass
+import pandas as pd
+from gs_quant.base import Market, EnumBase
+from gs_quant.common import AssetClass, CurrencyParameter, FiniteDifferenceParameter, AggregationLevel
 from gs_quant.context_base import do_not_serialise
 from gs_quant.target.risk import RiskMeasure as __RiskMeasure, RiskMeasureType, RiskMeasureUnit
 
+DEPRECATED_MEASURES = {'IRDeltaParallelLocalCcy': 'IRDelta',
+                       'InflationDeltaParallelLocalCcy': 'InflationDelta',
+                       'IRXccyDeltaParallelLocalCurrency': 'IRXccyDelta',
+                       'IRVegaParallelLocalCcy': 'IRVega',
+                       }
+
 
 class RiskMeasure(__RiskMeasure):
 
+    def __lt__(self, other):
+        return self.name < other.name
+
     def __repr__(self):
         return self.name or self.measure_type.name
 
@@ -54,7 +65,6 @@ class __RelativeRiskMeasure(RiskMeasure):
 
 
 class PnlExplain(__RelativeRiskMeasure):
-
     """ Pnl Explained """
 
     def __init__(self, to_market: Market):
@@ -76,7 +86,6 @@ class PnlExplainLive(PnlExplain):
 
 
 class PnlPredictLive(__RelativeRiskMeasure):
-
     """ Pnl Predicted """
 
     def __init__(self):
@@ -88,15 +97,88 @@ def __risk_measure_with_doc_string(name: str,
                                    doc: str,
                                    measure_type: RiskMeasureType,
                                    asset_class: Optional[AssetClass] = None,
-                                   unit: Optional[RiskMeasureUnit] = None
+                                   unit: Optional[RiskMeasureUnit] = None,
+                                   parameter_type: str = None
                                    ) -> RiskMeasure:
-    measure = RiskMeasure(measure_type=measure_type, asset_class=asset_class, unit=unit, name=name)
+    if parameter_type == "Currency":
+        measure = RiskMeasureWithCurrencyParameter(measure_type=measure_type, asset_class=asset_class, unit=unit,
+                                                   name=name)
+    elif parameter_type == "FiniteDifference":
+        measure = RiskMeasureWithFiniteDifferenceParameter(measure_type=measure_type, asset_class=asset_class,
+                                                           unit=unit, name=name)
+    else:
+        measure = RiskMeasure(measure_type=measure_type, asset_class=asset_class, unit=unit, name=name)
     measure.__doc__ = doc
     return measure
 
 
+class ParameterisedRiskMeasure(RiskMeasure):
+    def __init__(self, name: str = None, asset_class: Union[AssetClass, str] = None,
+                 measure_type: Union[RiskMeasureType, str] = None, unit: Union[RiskMeasureUnit, str] = None,
+                 value: Union[float, str] = None, parameter_type: str = None):
+        super().__init__(asset_class=asset_class, measure_type=measure_type, unit=unit, value=value, name=name)
+        self.parameter_type = parameter_type
+
+    def __repr__(self):
+        name = self.name or self.measure_type.name
+        params = None
+        if self.parameters:
+            params = self.parameters.as_dict()
+            params.pop('parameter_type', None)
+            sorted_keys = sorted(params.keys(), key=lambda x: x.lower())
+            params = ', '.join(
+                [f'{k}:{params[k].value if isinstance(params[k], EnumBase) else params[k]}' for k in sorted_keys])
+        return name + '(' + params + ')' if params else name
+
+    def parameter_is_empty(self):
+        return self.parameters is None
+
+
+class RiskMeasureWithCurrencyParameter(ParameterisedRiskMeasure):
+    def __call__(self, currency: str = None):
+        # hack to prevent ParameterisedRiskMeasure input into pandas LocIndexer as a callable function that returns
+        # output for indexing (https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.loc.html)
+        if isinstance(currency, pd.DataFrame):
+            return self
+
+        clone = copy.copy(self)
+        parameter = CurrencyParameter(value=currency)
+        clone.parameters = parameter
+        return clone
+
+
+class RiskMeasureWithFiniteDifferenceParameter(ParameterisedRiskMeasure):
+    def __call__(self, currency: str = None,
+                 aggregation_level: Union[AggregationLevel, str] = None, local_curve: bool = None,
+                 finite_difference_method: Union[FiniteDifferenceParameter, str] = None,
+                 mkt_marking_mode: str = None, bump_size: float = None, scale_factor: float = None, name: str = None):
+        # hack to prevent ParameterisedRiskMeasure input into pandas LocIndexer as a callable function that returns
+        # output for indexing (https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.loc.html)
+        if isinstance(currency, pd.DataFrame):
+            return self
+
+        clone = copy.copy(self)
+        if name:
+            clone.name = name
+        parameter = FiniteDifferenceParameter(aggregation_level=aggregation_level, currency=currency,
+                                              local_curve=local_curve, bump_size=bump_size,
+                                              finite_difference_method=finite_difference_method,
+                                              scale_factor=scale_factor, mkt_marking_mode=mkt_marking_mode)
+        clone.parameters = parameter
+        return clone
+
+
 DollarPrice = __risk_measure_with_doc_string('DollarPrice', 'Present value in USD', RiskMeasureType.Dollar_Price)
-Price = __risk_measure_with_doc_string('Price', 'Present value in local currency', RiskMeasureType.PV)
+Price = __risk_measure_with_doc_string('Price', 'Present value in local currency', RiskMeasureType.PV,
+                                       parameter_type="Currency")
+PricePips = __risk_measure_with_doc_string('Price', 'Present value in pips', RiskMeasureType.Price,
+                                           unit=RiskMeasureUnit.Pips,
+                                           parameter_type="Currency")
+Annuity = __risk_measure_with_doc_string('Annuity', 'Annuity', RiskMeasureType.AnnuityLocalCcy,
+                                         asset_class=AssetClass.Rates, parameter_type='Currency')
+
+CrossMultiplier = __risk_measure_with_doc_string('CrossMultiplier', 'Cross Multiplier',
+                                                 RiskMeasureType.Cross_Multiplier)
 ForwardPrice = __risk_measure_with_doc_string(
     'ForwardPrice',
     'Forward price',
@@ -148,9 +230,11 @@ FairVarStrike = __risk_measure_with_doc_string(
     'FairVarStrike',
     'Fair Variance Strike Value of a Variance Swap',
     RiskMeasureType.FairVarStrike)
-FXDelta = __risk_measure_with_doc_string('FXDelta', 'FX Delta', RiskMeasureType.Delta, asset_class=AssetClass.FX)
+FXDelta = __risk_measure_with_doc_string('FXDelta', 'FX Delta', RiskMeasureType.Delta, asset_class=AssetClass.FX,
+                                         parameter_type="FiniteDifference")
 FXGamma = __risk_measure_with_doc_string('FXGamma', 'FX Gamma', RiskMeasureType.Gamma, asset_class=AssetClass.FX)
-FXVega = __risk_measure_with_doc_string('FXVega', 'FX Vega', RiskMeasureType.Vega, asset_class=AssetClass.FX)
+FXVega = __risk_measure_with_doc_string('FXVega', 'FX Vega', RiskMeasureType.Vega, asset_class=AssetClass.FX,
+                                        parameter_type="FiniteDifference")
 FXSpot = __risk_measure_with_doc_string('FXSpot', 'FX Spot Rate', RiskMeasureType.Spot, asset_class=AssetClass.FX)
 FXAnnualATMImpliedVol = __risk_measure_with_doc_string(
     'FXAnnualATMImpliedVol',
@@ -168,47 +252,25 @@ IRBasis = __risk_measure_with_doc_string(
     'IRBasis',
     'Interest Rate Basis',
     RiskMeasureType.Basis,
-    asset_class=AssetClass.Rates)
-IRBasisParallel = __risk_measure_with_doc_string(
-    'IRBasisParallel',
-    'Interest Rate Parallel Basis',
-    RiskMeasureType.ParallelBasis,
-    asset_class=AssetClass.Rates)
+    asset_class=AssetClass.Rates, parameter_type="FiniteDifference")
+IRBasisParallel = IRBasis(aggregation_level=AggregationLevel.Asset, name='IRBasisParallel')
 InflationDelta = __risk_measure_with_doc_string(
     'InflationDelta',
     'Inflation Delta',
     RiskMeasureType.InflationDelta,
-    asset_class=AssetClass.Rates)
-InflationDeltaParallel = __risk_measure_with_doc_string(
-    'InflationDeltaParallel',
-    'Inflation Parallel Delta',
-    RiskMeasureType.ParallelInflationDelta,
-    asset_class=AssetClass.Rates)
-InflationDeltaParallelLocalCcy = __risk_measure_with_doc_string(
-    'InflationDeltaParallelLocalCcy',
-    'Inflation Parallel Delta (Local Ccy)',
-    RiskMeasureType.ParallelInflationDeltaLocalCcy,
-    asset_class=AssetClass.Rates)
+    asset_class=AssetClass.Rates, parameter_type='FiniteDifference')
+InflationDeltaParallel = InflationDelta(aggregation_level=AggregationLevel.Type, name='InflationDeltaParallel')
+InflationDeltaParallelLocalCcy = InflationDelta(aggregation_level=AggregationLevel.Type, currency='local',
+                                                name='InflationDeltaParallelLocalCcy')
 IRDelta = __risk_measure_with_doc_string(
     'IRDelta',
     'Interest Rate Delta',
     RiskMeasureType.Delta,
-    asset_class=AssetClass.Rates)
-IRDeltaParallel = __risk_measure_with_doc_string(
-    'IRDeltaParallel',
-    'Interest Rate Parallel Delta',
-    RiskMeasureType.ParallelDelta,
-    asset_class=AssetClass.Rates)
-IRDeltaLocalCcy = __risk_measure_with_doc_string(
-    'IRDeltaLocalCcy',
-    'Interest Rate Delta (Local Ccy)',
-    RiskMeasureType.DeltaLocalCcy,
-    asset_class=AssetClass.Rates)
-IRDeltaParallelLocalCcy = __risk_measure_with_doc_string(
-    'IRDeltaParallelLocalCcy',
-    'Interest Rate Parallel Delta (Local Ccy)',
-    RiskMeasureType.ParallelDeltaLocalCcy,
-    asset_class=AssetClass.Rates)
+    asset_class=AssetClass.Rates, parameter_type="FiniteDifference")
+IRDeltaParallel = IRDelta(aggregation_level=AggregationLevel.Asset, name='IRDeltaParallel')
+IRDeltaLocalCcy = IRDelta(currency='local', name='IRDeltaLocalCcy')
+IRDeltaParallelLocalCcy = IRDelta(aggregation_level=AggregationLevel.Type, currency='local',
+                                  name='IRDeltaParallelLocalCcy')
 IRDiscountDeltaParallel = __risk_measure_with_doc_string(
     'IRDiscountDeltaParallel',
     'Parallel Discount Delta',
@@ -223,17 +285,10 @@ IRXccyDelta = __risk_measure_with_doc_string(
     'IRXccyDelta',
     'Cross-ccy Delta',
     RiskMeasureType.XccyDelta,
-    asset_class=AssetClass.Rates)
-IRXccyDeltaParallel = __risk_measure_with_doc_string(
-    'IRXccyDeltaParallel',
-    'Cross-ccy Parallel Delta',
-    RiskMeasureType.ParallelXccyDelta,
-    asset_class=AssetClass.Rates)
-IRXccyDeltaParallelLocalCurrency = __risk_measure_with_doc_string(
-    'IRXccyDeltaParallelLocalCurrency',
-    'Cross-ccy Parallel Delta (Local Ccy)',
-    RiskMeasureType.ParallelXccyDeltaLocalCcy,
-    asset_class=AssetClass.Rates)
+    asset_class=AssetClass.Rates, parameter_type='FiniteDifference')
+IRXccyDeltaParallel = IRXccyDelta(aggregation_level=AggregationLevel.Type, name='IRXccyDeltaParallel')
+IRXccyDeltaParallelLocalCurrency = IRXccyDelta(aggregation_level=AggregationLevel.Type, currency='local',
+                                               name='IRXccyDeltaParallelLocalCurrency')
 IRGammaParallel = __risk_measure_with_doc_string(
     'IRGammaParallel',
     'Interest Rate Parallel Gamma',
@@ -248,22 +303,11 @@ IRVega = __risk_measure_with_doc_string(
     'IRVega',
     'Interest Rate Vega',
     RiskMeasureType.Vega,
-    asset_class=AssetClass.Rates)
-IRVegaParallel = __risk_measure_with_doc_string(
-    'IRVegaParallel',
-    'Interest Rate Parallel Vega',
-    RiskMeasureType.ParallelVega,
-    asset_class=AssetClass.Rates)
-IRVegaLocalCcy = __risk_measure_with_doc_string(
-    'IRVegaLocalCcy',
-    'Interest Rate Vega (Local Ccy)',
-    RiskMeasureType.VegaLocalCcy,
-    asset_class=AssetClass.Rates)
-IRVegaParallelLocalCcy = __risk_measure_with_doc_string(
-    'IRVegaParallelLocalCcy',
-    'Interest Rate Parallel Vega (Local Ccy)',
-    RiskMeasureType.ParallelVegaLocalCcy,
-    asset_class=AssetClass.Rates)
+    asset_class=AssetClass.Rates, parameter_type="FiniteDifference")
+IRVegaParallel = IRVega(aggregation_level=AggregationLevel.Asset, name='IRVegaParallel')
+IRVegaLocalCcy = IRVega(currency='local', name='IRVegaLocalCcy')
+IRVegaParallelLocalCcy = IRVega(aggregation_level=AggregationLevel.Type, currency='local',
+                                name='IRVegaParallelLocalCcy')
 IRAnnualImpliedVol = __risk_measure_with_doc_string(
     'IRAnnualImpliedVol',
     'Interest Rate Annual Implied Volatility (%)',
@@ -314,6 +358,11 @@ CDTheta = __risk_measure_with_doc_string(
     'Credit Theta',
     RiskMeasureType.Theta,
     asset_class=AssetClass.Credit)
+CDATMSpread = __risk_measure_with_doc_string(
+    'CDATMSpread',
+    'Credit ATM Spread',
+    RiskMeasureType.ATM_Spread,
+    asset_class=AssetClass.Credit)
 CRIFIRCurve = __risk_measure_with_doc_string(
     'CRIFIRCurve',
     'CRIF IR Curve',
@@ -348,3 +397,19 @@ ParSpread = __risk_measure_with_doc_string(
     'Par Spread',
     RiskMeasureType.Spread,
     asset_class=AssetClass.Rates)
+ATMSpread = __risk_measure_with_doc_string(
+    'ATMSpread',
+    'ATM Spread',
+    RiskMeasureType.Spread,
+    asset_class=AssetClass.Credit)
+FwdSpread = __risk_measure_with_doc_string(
+    'FwdSpread',
+    'Fwd Spread',
+    RiskMeasureType.Spread,
+    asset_class=AssetClass.Credit)
+ImpliedVolatility = __risk_measure_with_doc_string(
+    'ImpliedVolatility',
+    'Implied Volatility',
+    RiskMeasureType.Annual_Implied_Volatility,
+    unit=RiskMeasureUnit.Percent,
+    asset_class=AssetClass.Credit)
