@@ -133,7 +133,7 @@ def risk_by_class_handler(result: dict, risk_key: RiskKey, _instrument: Instrume
     types = [c['type'] for c in result['classes']]
     # list of risk by class measures exposed in gs-quant
     external_risk_by_class_val = ['IRBasisParallel', 'IRDeltaParallel', 'IRVegaParallel', 'PnlExplain']
-    if str(risk_key.risk_measure) in external_risk_by_class_val and len(types) <= 2 and len(set(types)) == 1:
+    if str(risk_key.risk_measure.name) in external_risk_by_class_val and len(types) <= 2 and len(set(types)) == 1:
         return FloatWithInfo(risk_key, sum(result.get('values', (float('nan'),))), unit=result.get('unit'),
                              request_id=request_id)
     else:
@@ -182,11 +182,10 @@ def risk_vector_handler(result: dict, risk_key: RiskKey, _instrument: Instrument
         ('mkt_quoting_style', 'quoteStyle'),
         ('value', 'value')
     )
-
     return __dataframe_handler(result['points'], mappings, risk_key, request_id=request_id)
 
 
-def risk_theta_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase,
+def risk_float_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase,
                        request_id: Optional[str] = None) -> FloatWithInfo:
     return FloatWithInfo(risk_key, result['values'][0], request_id=request_id)
 
@@ -233,7 +232,8 @@ result_handlers = {
     'Risk': risk_handler,
     'RiskByClass': risk_by_class_handler,
     'RiskVector': risk_vector_handler,
-    'RiskTheta': risk_theta_handler,
+    'RiskSecondOrderVector': risk_float_handler,
+    'RiskTheta': risk_float_handler,
     'Market': market_handler,
     'Unsupported': unsupported_handler
 }
