@@ -776,6 +776,7 @@ class AssetClassifications(Base):
         rating_second_highest: str = None,
         rating_linear: float = None,
         commod_template: str = None,
+        security_subtype: str = None,
         region: Union[Region, str] = None,
         name: str = None
     ):        
@@ -801,6 +802,7 @@ class AssetClassifications(Base):
         self.rating_second_highest = rating_second_highest
         self.rating_linear = rating_linear
         self.commod_template = commod_template
+        self.security_subtype = security_subtype
         self.region = region
         self.name = name
 
@@ -1014,6 +1016,16 @@ class AssetClassifications(Base):
         self._property_changed('commod_template')
         self.__commod_template = value        
 
+    @property
+    def security_subtype(self) -> str:
+        """Subtype of security."""
+        return self.__security_subtype
+
+    @security_subtype.setter
+    def security_subtype(self, value: str):
+        self._property_changed('security_subtype')
+        self.__security_subtype = value        
+
     @property
     def region(self) -> Union[Region, str]:
         """Regional classification for the asset"""
@@ -2570,7 +2582,7 @@ class AssetToInstrumentResponse(Base):
         asset_id: str,
         name: str,
         instrument: InstrumentBase,
-        size_field: str
+        size_field: str = None
     ):        
         super().__init__()
         self.asset_id = asset_id
