@@ -61,6 +61,9 @@ class ReportMeasures(EnumBase, Enum):
     exposure = 'exposure'
     sensitivity = 'sensitivity'
     mctr = 'mctr'
+    annualizedMCTRisk = 'annualizedMCTRisk'
+    annualizedRMCTRisk = 'annualizedRMCTRisk'
+    poRisk = 'poRisk'
     price = 'price'
     basePrice = 'basePrice'    
 
@@ -88,6 +91,7 @@ class ReportType(EnumBase, Enum):
     Portfolio_Aging = 'Portfolio Aging'
     Portfolio_Thematic_Analytics = 'Portfolio Thematic Analytics'
     Asset_Factor_Risk = 'Asset Factor Risk'
+    Asset_Thematic_Analytics = 'Asset Thematic Analytics'
     Basket_Create = 'Basket Create'
     Basket_Backcast = 'Basket Backcast'
     Basket_Rebalance_Auto_Approval = 'Basket Rebalance Auto Approval'
@@ -96,11 +100,7 @@ class ReportType(EnumBase, Enum):
     Backtest_Run = 'Backtest Run'
     Analytics = 'Analytics'
     Risk_Calculation = 'Risk Calculation'
-    PCO_Generate_Orders = 'PCO Generate Orders'
-    PCO_Update_Parameters = 'PCO Update Parameters'
-    PCO_Update_Client_Data = 'PCO Update Client Data'
-    PCO_Update_Open_Hedge_Notional = 'PCO Update Open Hedge Notional'
-    PCO_Add_Order = 'PCO Add Order'    
+    PCO = 'PCO'    
 
 
 class ParametersOverrides(Base):
@@ -143,6 +143,7 @@ class Report(Base):
         created_by_id: str = None,
         created_time: datetime.datetime = None,
         entitlements: Entitlements = None,
+        earliest_start_date: datetime.date = None,
         entitlement_exclusions: EntitlementExclusions = None,
         id_: str = None,
         last_updated_by_id: str = None,
@@ -162,6 +163,7 @@ class Report(Base):
         self.created_by_id = created_by_id
         self.created_time = created_time
         self.entitlements = entitlements
+        self.earliest_start_date = earliest_start_date
         self.entitlement_exclusions = entitlement_exclusions
         self.__id = id_
         self.last_updated_by_id = last_updated_by_id
@@ -238,6 +240,16 @@ class Report(Base):
         self._property_changed('entitlements')
         self.__entitlements = value        
 
+    @property
+    def earliest_start_date(self) -> datetime.date:
+        """ISO 8601-formatted date"""
+        return self.__earliest_start_date
+
+    @earliest_start_date.setter
+    def earliest_start_date(self, value: datetime.date):
+        self._property_changed('earliest_start_date')
+        self.__earliest_start_date = value        
+
     @property
     def entitlement_exclusions(self) -> EntitlementExclusions:
         """Defines the exclusion entitlements of a given resource."""
