@@ -41,6 +41,17 @@ class Term(EnumBase, Enum):
         return self.value
 
 
+class RiskModelEventType(EnumBase, Enum):
+    """Indicates what type of risk model event to check for"""
+
+    risk_model = 'Risk Model'
+    risk_model_pfp_data = 'Risk Model PFP Data'
+    risk_model_isc_data = 'Risk Model ISC Data'
+
+    def __repr__(self):
+        return self.value
+
+
 class UniverseIdentifier(EnumBase, Enum):
     """Identifier by which risk model is uploaded"""
 
@@ -53,6 +64,21 @@ class UniverseIdentifier(EnumBase, Enum):
         return self.value
 
 
+class RiskModelUniverseIdentifierRequest(EnumBase, Enum):
+    """Identifier by which risk model data is queried"""
+
+    gsid = 'gsid'
+    bbid = 'bbid'
+    cusip = 'cusip'
+    sedol = 'sedol'
+    ric = 'ric'
+    ticker = 'ticker'
+    prime_id = 'primeId'
+
+    def __repr__(self):
+        return self.value
+
+
 class FactorType(EnumBase, Enum):
     """Factor represents a risk factor and Category represents a risk factor category"""
 
@@ -284,11 +310,11 @@ class FactorPortfolio(Base):
     def __init__(
             self,
             factor_id: str,
-            weight: List[float]
+            weights: List[float]
     ):
         super().__init__()
         self.factor_id = factor_id
-        self.weight = weight
+        self.weights = weights
 
     @property
     def factor_id(self) -> str:
@@ -301,12 +327,12 @@ class FactorPortfolio(Base):
         self.__factor_id = value
 
     @property
-    def weight(self) -> List[float]:
+    def weights(self) -> List[float]:
         """Weights for each asset in the portfolio"""
         return self.__weight
 
-    @weight.setter
-    def weight(self, value: List[float]):
+    @weights.setter
+    def weights(self, value: List[float]):
         self._property_changed('weight')
         self.__weight = value
 
@@ -349,22 +375,22 @@ class DataAssetsRequest(Base):
     @camel_case_translate
     def __init__(
             self,
-            identifier: Union[UniverseIdentifier, str],
+            identifier: Union[RiskModelUniverseIdentifierRequest, str],
             universe: List[str]
     ):
         super().__init__()
-        self.identifier = get_enum_value(UniverseIdentifier, identifier)
+        self.identifier = get_enum_value(RiskModelUniverseIdentifierRequest, identifier)
         self.universe = universe
 
     @property
-    def identifier(self) -> Union[UniverseIdentifier, str]:
+    def identifier(self) -> Union[RiskModelUniverseIdentifierRequest, str]:
         """The identifier by which the risk model is queried"""
         return self.__identifier
 
     @identifier.setter
-    def identifier(self, value: Union[UniverseIdentifier, str]):
+    def identifier(self, value: Union[RiskModelUniverseIdentifierRequest, str]):
         self._property_changed('identifier')
-        self.__identifier = get_enum_value(UniverseIdentifier, value)
+        self.__identifier = get_enum_value(RiskModelUniverseIdentifierRequest, value)
 
     @property
     def universe(self) -> List[str]:
