@@ -16,9 +16,12 @@ under the License.
 import datetime as dt
 from unittest import mock
 
+import numpy as np
 import pandas as pd
 
 import gs_quant.risk as risk
+from gs_quant.api.gs.assets import GsAssetApi
+from gs_quant.api.gs.portfolios import GsPortfolioApi
 from gs_quant.datetime import business_day_offset
 from gs_quant.instrument import IRSwap, IRSwaption, CurveScenario
 from gs_quant.markets import HistoricalPricingContext, PricingContext, BackToTheFuturePricingContext, \
@@ -26,6 +29,8 @@ from gs_quant.markets import HistoricalPricingContext, PricingContext, BackToThe
 from gs_quant.markets.portfolio import Portfolio
 from gs_quant.risk.results import PortfolioPath, PortfolioRiskResult
 from gs_quant.session import Environment, GsSession
+from gs_quant.target.common import PositionSet
+from gs_quant.target.portfolios import Portfolio as MarqueePortfolio
 from gs_quant.test.utils.test_utils import MockCalc
 
 
@@ -36,7 +41,6 @@ def set_session():
 
 
 def test_portfolio(mocker):
-
     with MockCalc(mocker):
         with PricingContext(pricing_date=dt.date(2020, 10, 15)):
             swap1 = IRSwap('Pay', '10y', 'USD', fixed_rate=0.001, name='swap_10y@10bp')
@@ -81,6 +85,24 @@ def test_portfolio(mocker):
         assert len(portfolio) == 3
 
 
+def test_construction():
+    swap1 = IRSwap('Pay', '10y', 'USD')
+    swap2 = IRSwap('Pay', '5y', 'USD')
+    my_list = [swap1, swap2]
+    my_tuple = (swap1, swap2)
+    my_np_arr = np.array((swap1, swap2))
+
+    p1 = Portfolio(my_list)
+    p2 = Portfolio(my_tuple)
+    p3 = Portfolio(my_np_arr)
+
+    assert len(p1) == 2
+    assert len(p2) == 2
+    assert len(p3) == 2
+    assert p1 == p2
+    assert p2 == p3
+
+
 def test_historical_pricing(mocker):
     with MockCalc(mocker):
         swap1 = IRSwap('Pay', '10y', 'USD', fixed_rate='ATM+1', name='10y@a+1')
@@ -145,7 +167,6 @@ def test_backtothefuture_pricing(mocker):
 
 def test_duplicate_instrument(mocker):
     with MockCalc(mocker):
-
         swap1 = IRSwap('Pay', '1y', 'EUR', name='EUR1y')
         swap2 = IRSwap('Pay', '2y', 'EUR', name='EUR2y')
         swap3 = IRSwap('Pay', '3y', 'EUR', name='EUR3y')
@@ -181,7 +202,6 @@ def test_nested_portfolios(mocker):
 
 def test_single_instrument(mocker):
     with MockCalc(mocker):
-
         swap1 = IRSwap('Pay', '10y', 'USD', fixed_rate=0.0, name='10y@0')
 
         portfolio = Portfolio(swap1)
@@ -322,7 +342,6 @@ def test_from_frame():
 
 
 def test_single_instrument_new_mock(mocker):
-
     with MockCalc(mocker):
         with PricingContext(pricing_date=dt.date(2020, 10, 15)):
             swap1 = IRSwap('Pay', '10y', 'USD', name='swap1')
@@ -334,3 +353,20 @@ def test_single_instrument_new_mock(mocker):
         assert tuple(map(lambda x: round(x, 6), fwd)) == (0.007512,)
         assert round(fwd.aggregate(), 2) == 0.01
         assert round(fwd[swap1], 6) == 0.007512
+
+
+def test_get_instruments(mocker):
+    mocker.patch.object(GsPortfolioApi, 'get_position_dates', return_value=([dt.date(2021, 1, 2),
+                                                                             dt.date(2021, 5, 6),
+                                                                             dt.date(2021, 6, 1)]))
+    mocker.patch.object(GsPortfolioApi, 'get_positions_for_date', return_value=(PositionSet(
+        position_date=dt.date(2021, 6, 1),
+        positions=[])))
+    mocker.patch.object(GsPortfolioApi, 'get_portfolio', return_value=(MarqueePortfolio(id_='id',
+                                                                                        name='name',
+                                                                                        currency='USD')))
+    mocker.patch.object(GsAssetApi, 'get_instruments_for_positions', return_value=([]))
+
+    port = Portfolio.get(portfolio_id='id')
+    port._get_instruments(dt.date(2021, 5, 14), False)
+    GsPortfolioApi.get_positions_for_date.assert_called_with('id', dt.date(2021, 5, 6))
