@@ -65,14 +65,14 @@ def test_create_risk_model(mocker):
     mocker.patch.object(GsSession.current, '_post', return_value=mock_risk_model_obj)
     new_model = FactorRiskModel(risk_model_id,
                                 'Fake Risk Model',
-                                'Country',
-                                'Long',
-                                'gsid',
+                                CoverageType.Country,
+                                Term.Long,
+                                UniverseIdentifier.gsid,
                                 'GS',
                                 0.1,
                                 entitlements={},
                                 description='Test')
-    new_model.upload()
+    new_model.save()
     assert new_model.id == mock_risk_model_obj.id
     assert new_model.name == mock_risk_model_obj.name
     assert new_model.description == mock_risk_model_obj.description
