@@ -85,7 +85,7 @@ def last(x: pd.Series) -> pd.Series:
     :func:`first`
 
     """
-    return pd.Series(x[-1], x.index)
+    return pd.Series(x.dropna()[-1], x.index)
 
 
 @plot_function
@@ -114,7 +114,7 @@ def last_value(x: pd.Series) -> Union[int, float]:
     """
     if x.empty:
         raise MqValueError("cannot get last value of an empty series")
-    return x.iloc[-1]
+    return x.dropna().iloc[-1]
 
 
 @plot_function
@@ -190,6 +190,52 @@ def diff(x: pd.Series, obs: int = 1) -> pd.Series:
     return ret_series
 
 
+@plot_function
+def compare(x: Union[pd.Series, Real], y: Union[pd.Series, Real], method: Interpolate = Interpolate.STEP) \
+        -> Union[pd.Series, Real]:
+    """
+    Compare two series or scalars against each other
+
+    :param x: timeseries or scalar
+    :param y: timeseries or scalar
+    :param method: interpolation method (default: step). Only used when both x and y are timeseries
+    :return: binary timeseries with the result of x relation y or the comparison of the given real numbers
+
+    **Usage**
+
+    Compare two series or scalar variables applying the given interpolation method in case indices of :math:`x`
+    and :math:`y` differ. Returns a signal with values of 1, 0, or -1.
+
+    If :math:`X_t > Y_t`, then :math:`R_t = 1`.
+    If :math:`X_t = Y_t`, then :math:`R_t = 0`.
+    If :math:`X_t < Y_t`, then :math:`R_t = -1`.
+
+    Alignment operators:
+
+    =========   ========================================================================
+    Method      Behavior
+    =========   ========================================================================
+    intersect   Resultant series only has values on the intersection of dates.
+                Values for dates present in only one series will be ignored
+    nan         Resultant series has values on the union of dates in both series. Values
+                for dates only available in one series will be treated as nan in the
+                other series, and therefore in the resultant series
+    zero        Resultant series has values on the union of dates in both series. Values
+                for dates only available in one series will be treated as zero in the
+                other series
+    step        Resultant series has values on the union of dates in both series. Values
+                for dates only available in one series will be interpolated via step
+                function in the other series
+    time        Resultant series have values on the union of dates / times. Missing
+                values surrounded by valid values will be interpolated given length of
+                interval. Input series must use DateTimeIndex.
+    =========   ========================================================================
+    """
+    x, y = align(x, y, method)
+
+    return (x > y) * 1.0 + (x < y) * -1.0
+
+
 class LagMode(Enum):
     TRUNCATE = "truncate"
     EXTEND = "extend"
