@@ -15,11 +15,10 @@ under the License.
 """
 
 from dateutil.relativedelta import relativedelta as rdelta
-from functools import reduce
 
 from gs_quant.timeseries.helper import _create_enum
 from gs_quant.timeseries.measures_helper import EdrDataReference, VolReference, preprocess_implied_vol_strikes_eq
-from gs_quant.timeseries.econometrics import volatility
+from gs_quant.timeseries.econometrics import volatility, correlation
 from .statistics import *
 from ..api.gs.assets import GsAssetApi
 from ..api.gs.data import GsDataApi, MarketDataResponseFrame
@@ -195,12 +194,13 @@ class Basket:
 
     def get_marquee_ids(self):
         if self._marquee_ids is None:
-            assets = GsAssetApi.get_many_assets_data(bbid=self.bbids, fields=('id', ))
-            self._marquee_ids = [a['id'] for a in assets]
-
-            if len(self._marquee_ids) != len(self.bbids):
+            assets = GsAssetApi.get_many_assets_data(bbid=self.bbids, fields=('id', 'bbid'), limit=len(self.bbids))
+            assets_dict = {entry['bbid']: entry['id'] for entry in assets}
+            if len(assets_dict) != len(set(self.bbids)):
                 raise MqValueError('Unable to find all stocks')
 
+            self._marquee_ids = [assets_dict[bbid] for bbid in self.bbids]
+
         return self._marquee_ids
 
     def _ensure_spot_data(self, request_id: Optional[str] = None):
@@ -263,7 +263,8 @@ class Basket:
     @requires_session
     @plot_method
     def average_implied_volatility(self, tenor: str, strike_reference: EdrDataReference, relative_strike: Real, *,
-                                   real_time: bool = False, request_id: Optional[str] = None) -> pd.Series:
+                                   real_time: bool = False, request_id: Optional[str] = None,
+                                   source: Optional[str] = None) -> pd.Series:
         """
         Weighted average implied volatility
 
@@ -272,6 +273,7 @@ class Basket:
         :param relative_strike: strike relative to reference
         :param real_time: whether to retrieve intraday data instead of EOD
         :param request_id: service request id, if any
+        :param source: name of function caller
         :return: time series of the average implied volatility
         """
 
@@ -288,6 +290,7 @@ class Basket:
             self.get_marquee_ids(),
             QueryType.IMPLIED_VOLATILITY,
             where=where,
+            source=source,
             real_time=real_time
         )
         log_debug(request_id, _logger, 'q %s', query)
@@ -321,6 +324,41 @@ class Basket:
 
         vols = [volatility(spot_df[asset_id], Window(tenor, tenor), returns_type) for asset_id in spot_df]
         vols = pd.concat(vols, axis=1)
-        vols.columns = self.get_marquee_ids()
+        vols.columns = list(spot_df)
 
-        return actual_weights.mul(vols).sum(axis=1, skipna=False)
+        return actual_weights.mul(vols, axis=1).sum(axis=1, skipna=False)
+
+    @requires_session
+    @plot_method
+    def average_realized_correlation(self, w: Union[Window, int, str] = Window(None, 0),
+                                     *, real_time: bool = False, request_id: Optional[str] = None) -> pd.Series:
+        """
+        Weighted average realized correlation. Computes the correlation between each of the basket's constituents and
+        returns their average, weighted by their representation in the basket.
+
+        :param w: Window, int, or str: size of window and ramp up to use. e.g. Window(22, 10) where 22 is the window
+            size and 10 the ramp up value. If w is a string, it should be a relative date like '1m', '1d', etc.
+            Window size defaults to length of series.
+        :param real_time: whether to retrieve intraday data instead of EOD
+        :param request_id: service request ID, if any
+        :return: time series of the average realized correlation
+        """
+        # Calculated using method (a) from here: http://www.nematrian.com/MeasuringAverageStockCorrelation
+        # Could be sped-up by using another estimate method, such as (b)
+        if real_time:
+            raise NotImplementedError('real-time basket realized corr not implemented')
+
+        spot_df = self.get_spot_data(request_id=request_id)
+        actual_weights = self.get_actual_weights(request_id=request_id)
+
+        tot = pd.Series(np.zeros_like(spot_df.iloc[:, 0]), index=spot_df.index)
+        tot_wt = pd.Series(np.zeros_like(spot_df.iloc[:, 0]), index=spot_df.index)
+        # Iterate through and compute pairwise correlation between spot price series,
+        # averaging at the end.
+        for i in range(len(spot_df.columns)):
+            for j in range(i + 1, len(spot_df.columns)):
+                corr = correlation(spot_df.iloc[:, i], spot_df.iloc[:, j], w)
+                wt = actual_weights.iloc[:, i] * actual_weights.iloc[:, j]
+                tot += corr * wt
+                tot_wt += wt
+        return pd.to_numeric(tot / tot_wt, errors='coerce')
