@@ -515,6 +515,42 @@ def date_range(x: pd.Series, start_date: Union[date, int], end_date: Union[date,
     return x.loc[x.index.intersection(list(_date_range(start_date, end_date, week_mask=week_mask)))]
 
 
+@plot_function
+def append(series: List[pd.Series]) -> pd.Series:
+    """
+    Append data series
+
+    :param series: an array of timeseries
+    :return: concatenated timeseries
+
+    **Usage**
+
+    For input series [:math:`x_1`, :math:`x_2`, ... , :math:`x_n`], takes data from series :math:`x_i` until
+    that series runs out, then appends data from `x_{i+1}` until that series runs out.
+
+    **Examples**
+
+    Append two series:
+
+    >>> x = generate_series(100)
+    >>> y = generate_series(100)
+    >>> append([x, y])
+
+    **See also**
+
+    :func:`prepend`
+
+    """
+    if not len(series):
+        return pd.Series(dtype='float64')
+    res = series[0].copy()
+    for i in range(1, len(series)):
+        cur = series[i]
+        start = res.index[-1]
+        res = res.append(cur.loc[cur.index > start])
+    return res
+
+
 @plot_function
 def prepend(x: List[pd.Series]) -> pd.Series:
     """
@@ -616,7 +652,12 @@ def bucketize(series: pd.Series, aggregate_function: AggregateFunction, period:
     series.index = pd.to_datetime(series.index)
     frequency = period.value[0].upper()
     agg = aggregate_function.value
-    return series.resample(frequency).apply(agg)
+    result = series.resample(frequency).apply(agg)
+
+    last_timestamp = min(series.index[-1], result.index[-1])
+    idx = result.index[:-1].insert(len(result) - 1, last_timestamp)
+    result.index = idx
+    return result
 
 
 @plot_function
