@@ -21,11 +21,10 @@ from pydash import decapitalize
 from gs_quant.api.gs.data import QueryType
 from gs_quant.data.core import DataContext
 from gs_quant.entities.entity import EntityType
-from gs_quant.markets.factor import Factor
 from gs_quant.markets.securities import Asset
 from gs_quant.models.risk_model import FactorRiskModel, ReturnFormat
 from gs_quant.target.common import AssetClass, AssetType
-from gs_quant.target.risk_models import Measure, DataAssetsRequest, UniverseIdentifier
+from gs_quant.target.risk_models import Measure, DataAssetsRequest, RiskModelUniverseIdentifierRequest
 from gs_quant.timeseries import plot_measure_entity, plot_measure, prices
 from gs_quant.timeseries.measures import _extract_series_from_df
 
@@ -44,16 +43,16 @@ def factor_zscore(asset: Asset, risk_model_id: str, factor_name: str, *,
     :param request_id: service request id, if any
     :return: Time-series of asset factor exposure across available risk model dates
     """
-    risk_model = FactorRiskModel.get(risk_model_id)
-    factor = Factor.get(risk_model_id, factor_name)
+    model = FactorRiskModel.get(risk_model_id)
+    factor = model.get_factor(factor_name)
     gsid = asset.get_identifier('GSID')
 
     # Query risk model data
-    query_results = risk_model.get_data(
+    query_results = model.get_data(
         measures=[Measure.Factor_Name, Measure.Universe_Factor_Exposure, Measure.Asset_Universe],
         start_date=DataContext.current.start_time,
         end_date=DataContext.current.end_time,
-        assets=DataAssetsRequest(identifier=UniverseIdentifier.gsid, universe=[gsid])
+        assets=DataAssetsRequest(identifier=RiskModelUniverseIdentifierRequest.gsid, universe=[gsid])
     ).get('results', [])
 
     # Get the factor data from query results
@@ -81,8 +80,9 @@ def factor_covariance(risk_model_id: str, factor_name_1: str, factor_name_2: str
     :return: Time-series of covariances between the two factors across available risk model dates
     """
 
-    factor_1 = Factor.get(risk_model_id, factor_name_1)
-    factor_2 = Factor.get(risk_model_id, factor_name_2)
+    model = FactorRiskModel.get(risk_model_id)
+    factor_1 = model.get_factor(factor_name_1)
+    factor_2 = model.get_factor(factor_name_2)
     covariance_curve = factor_1.covariance(factor_2,
                                            DataContext.current.start_date,
                                            DataContext.current.end_date,
@@ -103,7 +103,8 @@ def factor_volatility(risk_model_id: str, factor_name: str, *, source: str = Non
     :param request_id: server request id
     :return: Time-series of a factor's volatility across available risk model dates
     """
-    factor = Factor.get(risk_model_id, factor_name)
+    model = FactorRiskModel.get(risk_model_id)
+    factor = model.get_factor(factor_name)
     volatility = factor.volatility(DataContext.current.start_date,
                                    DataContext.current.end_date,
                                    ReturnFormat.JSON)
@@ -124,8 +125,9 @@ def factor_correlation(risk_model_id: str, factor_name_1: str, factor_name_2: st
     :param request_id: server request id
     :return: Time-series of correlations between the two factors across available risk model dates
     """
-    factor_1 = Factor.get(risk_model_id, factor_name_1)
-    factor_2 = Factor.get(risk_model_id, factor_name_2)
+    model = FactorRiskModel.get(risk_model_id)
+    factor_1 = model.get_factor(factor_name_1)
+    factor_2 = model.get_factor(factor_name_2)
     correlation = factor_1.correlation(factor_2,
                                        DataContext.current.start_date,
                                        DataContext.current.end_date,
@@ -147,7 +149,8 @@ def factor_performance(risk_model_id: str, factor_name: str, *, source: str = No
     :return: Time-series of factor returns as a price series across available risk model dates
     """
 
-    factor = Factor.get(risk_model_id, factor_name)
+    model = FactorRiskModel.get(risk_model_id)
+    factor = model.get_factor(factor_name)
     factor_returns = factor.returns(DataContext.current.start_date,
                                     DataContext.current.end_date,
                                     ReturnFormat.JSON)
